import path = require('path');
import utils = require('./utils');


// Make sure we have required command line arguments.
if (process.argv.length !== 3) {
  let msg = '** Must supply a library name\n';
  process.stderr.write(msg);
  process.exit(1);
}


let name = process.argv[2];

// Handle the packages
utils.getLernaPaths().forEach(function (pkgPath) {
  handlePackage(pkgPath);
});
handlePackage(path.resolve('.'));


/**
 * Handle an individual package on the path - update the dependency.
 */
function handlePackage(packagePath: string): void {
  // Read in the package.json.
  packagePath = path.join(packagePath, 'package.json');
  let data: any;
  try {
    data = require(packagePath);
  } catch (e) {
    console.log('Skipping package ' + packagePath);
    return;
  }

  // Update dependencies as appropriate.
  if (name in data['dependencies']) {
    delete data['dependencies'][name];
  } else if (name in data['devDependencies']) {
    delete data['devDependencies'][name];
  }

  // Write the file back to disk.
  utils.ensurePackageData(data, packagePath);
}
